
## CATO-CLI - query.servicePrincipalAdmin:
[Click here](https://api.catonetworks.com/documentation/#query-query.servicePrincipalAdmin) for documentation on this operation.

### Usage for query.servicePrincipalAdmin:

```bash
catocli query servicePrincipalAdmin -h

catocli query servicePrincipalAdmin <json>

catocli query servicePrincipalAdmin --json-file query.servicePrincipalAdmin.json

catocli query servicePrincipalAdmin '{"adminID":"id"}'

catocli query servicePrincipalAdmin '{
    "adminID": "id"
}'
```

#### Operation Arguments for query.servicePrincipalAdmin ####

`accountId` [ID] - (required) N/A    
`adminID` [ID] - (required) N/A    
